<?php

namespace Drupal\entity_display_json\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns a JSON response with site information.
 */
class EntityDisplayJsonInfo extends ControllerBase {

  /**
   * The site configuration.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $siteConfig;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EntityDisplayJsonController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   The language manager service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, LanguageManagerInterface $languageManager, EntityTypeManagerInterface $entityTypeManager) {
    $this->siteConfig = $configFactory->get('system.site');
    $this->languageManager = $languageManager;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('language_manager'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Returns a JSON response with site information.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function getInfo() {
    $siteName = $this->siteConfig->get('name');
    $siteSlogan = $this->siteConfig->get('slogan');
    $homepageUrl = $this->siteConfig->get('page.front');
    $defaultLanguage = $this->languageManager->getDefaultLanguage()->getId();

    $response = [
      'apiVersion' => '1.0',
      'site_name' => $siteName,
      'site_slogan' => $siteSlogan,
      'default_language' => $defaultLanguage,
      'homepage_url' => $homepageUrl,
    ];

    if (strpos($homepageUrl, '/node') !== FALSE) {
      $nid = str_replace('/node/', '', $homepageUrl);
      $node = $this->entityTypeManager->getStorage('node')->load($nid);
      $uuid = $node->uuid();
      $response['homepage_uuid'] = $uuid;
      $response['homepage_entity_type'] = 'node';
    }

    return new JsonResponse($response);
  }

}
